#!/usr/bin/env python2
# -*- coding: utf-8 -*-

# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA

""" koji module of flr """

import flr
import subprocess

# Base koji command
KOJI_CMD = "koji"


def move_builds(src_tag, dest_tag, builds):
    """
    Move a build between two different tags in koji

    :param src_tag: str, the source/origin koji tag
    :param dest_tag: str, the destination koji tag
    :param builds: list of str, a list of one or many koji builds
    """

    # Compose the koji command
    cmd = [
        KOJI_CMD,
        "move-build",
        src_tag,
        dest_tag,
        ' '.join(builds),
    ]

    # Execute the koji command
    flr.log.info("Running command: {0}".format(cmd))
    subprocess.call(cmd)


def latest_build(tag, pkgs):
    """
    Get a list from koji of the latest build for one or many packages

    :param tag: str, the koji tag to query for the latest package
    :param pkgs: list of str, a list of one or many packages to query for
    """

    # Compose the koji command
    cmd = [
        KOJI_CMD,
        "-q latest-build",
        tag,
        ' '.join(pkgs)
    ]

    # Execute the koji command
    flr.log.info("Running command: {0}".format(cmd))
    subproc = subprocess.Popen(
        cmd,
        stdout=subprocess.PIPE,
        stderr=subprocess.PIPE
    )
    # Capture the output
    stdout, stderr = subproc.communicate()

    # Parse the output and return the first element of each line (build name)
    return [x.split()[0] for x in stdout.strip().split('\n')]


def import_signatures(pkg_paths):
    """
    Import a signatures into koji

    :param pkg_paths: list of str, list of paths to signed rpms who's
        signatures need importing
    """

    # Bash equivalent
    #
    # koji import-signature  tmp/signed/*

    # Compose the koji command
    cmd = [
        KOJI_CMD,
        "import-sig",
        ' '.join(pkg_paths)
    ]

    # Execute the koji command
    flr.log.info("Running command: {0}".format(cmd))
    subprocess.call(cmd)


def write_signed_rpms(key_sig, builds):
    """
    Write our signed rpms from koji

    :param key_sig: str, koji key signature
    :param builds: list of str, list of koji builds n-v-r
    """

    # Bash equivalent
    #
    # koji write-signed-rpm 81b46521 openh264-1.5.2-0.3.git21e44bd.fc24

    # Compose the koji command
    cmd = [
        KOJI_CMD,
        "write-signed-rpm",
        key_sig,
        ' '.join(builds)
    ]

    # Execute the koji command
    flr.log.info("Running command: {0}".format(cmd))
    subprocess.call(cmd)


# vim: tabstop=8 expandtab shiftwidth=4 softtabstop=4
